Select one filing per organization-year
panel_deduplicate.RdPrefers non-group and non-partial filings, then amended filings, then the most recent timestamp. At least one filing is retained per organization-year.
Usage
panel_deduplicate(
data,
id = "EIN2",
year = "TAX_YEAR",
group = "RETURN_GROUP_X",
partial = "RETURN_PARTIAL_X",
amended = "RETURN_AMENDED_X",
timestamp = "RETURN_TIME_STAMP",
verbose = TRUE
)
deduplicate(
data,
id = "EIN2",
year = "TAX_YEAR",
group = "RETURN_GROUP_X",
partial = "RETURN_PARTIAL_X",
amended = "RETURN_AMENDED_X",
timestamp = "RETURN_TIME_STAMP",
verbose = TRUE
)Value
A data frame with at most one row per ID-year (or the panel, given a
panel). deduplicate() is a deprecated alias.