Resolve aliases and literal efile table names
resolve_tables.RdAny non-empty literal table name is accepted, allowing newly published and user-specified tables without a package update.
Usage
resolve_tables(tables, source = data_source())Arguments
- tables
Character vector of aliases or canonical table names.
- source
An
data_source()configuration.
Value
A data frame containing request, table, alias status, cardinality, and
whether the resolved name is in the canonical table_catalog().